/* selectionbar.c generated by valac 0.38.4, the Vala compiler
 * generated from selectionbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libcommon.h>
#include <stdlib.h>
#include <string.h>
#include <glib/gi18n-lib.h>


#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;
typedef struct _BoxesSelectionbarPrivate BoxesSelectionbarPrivate;

#define BOXES_TYPE_APP_WINDOW (boxes_app_window_get_type ())
#define BOXES_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindow))
#define BOXES_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))
#define BOXES_IS_APP_WINDOW(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP_WINDOW))
#define BOXES_IS_APP_WINDOW_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP_WINDOW))
#define BOXES_APP_WINDOW_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP_WINDOW, BoxesAppWindowClass))

typedef struct _BoxesAppWindow BoxesAppWindow;
typedef struct _BoxesAppWindowClass BoxesAppWindowClass;
enum  {
	BOXES_SELECTIONBAR_0_PROPERTY,
	BOXES_SELECTIONBAR_NUM_PROPERTIES
};
static GParamSpec* boxes_selectionbar_properties[BOXES_SELECTIONBAR_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _Block73Data Block73Data;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_UI_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_UI, BoxesUIIface))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIIface BoxesUIIface;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PROPERTY (boxes_property_get_type ())
#define BOXES_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTY, BoxesProperty))
#define BOXES_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTY, BoxesPropertyClass))
#define BOXES_IS_PROPERTY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTY))
#define BOXES_IS_PROPERTY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTY))
#define BOXES_PROPERTY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTY, BoxesPropertyClass))

typedef struct _BoxesProperty BoxesProperty;
typedef struct _BoxesPropertyClass BoxesPropertyClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_MACHINE_TYPE_CONNECT_FLAGS (boxes_machine_connect_flags_get_type ())
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
typedef struct _Block74Data Block74Data;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_NOTIFICATION (boxes_notification_get_type ())
#define BOXES_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotification))
#define BOXES_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))
#define BOXES_IS_NOTIFICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATION))
#define BOXES_IS_NOTIFICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATION))
#define BOXES_NOTIFICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATION, BoxesNotificationClass))

typedef struct _BoxesNotification BoxesNotification;
typedef struct _BoxesNotificationClass BoxesNotificationClass;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;

struct _BoxesSelectionbar {
	GtkRevealer parent_instance;
	BoxesSelectionbarPrivate * priv;
};

struct _BoxesSelectionbarClass {
	GtkRevealerClass parent_class;
};

struct _BoxesSelectionbarPrivate {
	GtkToggleButton* favorite_btn;
	GtkButton* pause_btn;
	GtkButton* remove_btn;
	GtkButton* open_btn;
	BoxesAppWindow* window;
	gboolean ignore_favorite_btn_clicks;
};

struct _Block73Data {
	int _ref_count_;
	BoxesSelectionbar* self;
	BoxesAppWindow* window;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUIIface {
	GTypeInterface parent_iface;
	BoxesUIState (*get_previous_ui_state) (BoxesUI* self);
	void (*set_previous_ui_state) (BoxesUI* self, BoxesUIState value);
	BoxesUIState (*get_ui_state) (BoxesUI* self);
	void (*set_ui_state) (BoxesUI* self, BoxesUIState value);
};

struct _BoxesCollectionItem {
	GObject parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	GObjectClass parent_class;
	gint (*compare) (BoxesCollectionItem* self, BoxesCollectionItem* other);
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_GENERAL,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_SNAPSHOTS,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

typedef enum  {
	BOXES_MACHINE_CONNECT_FLAGS_NONE = 0,
	BOXES_MACHINE_CONNECT_FLAGS_IGNORE_SAVED_STATE = 1 << 0
} BoxesMachineConnectFlags;

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesCollectionSource* source;
	BoxesBoxConfig* config;
	gboolean stay_on_display;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*save_real) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*save_real_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	void (*connect_display) (BoxesMachine* self, BoxesMachineConnectFlags flags, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*connect_display_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	void (*restart) (BoxesMachine* self);
	void (*clone) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	void (*clone_finish) (BoxesMachine* self, GAsyncResult* _res_);
	void (*disconnect_display) (BoxesMachine* self);
	void (*update_status) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
	gboolean (*get_suspend_at_exit) (BoxesMachine* self);
	gboolean (*get_can_save) (BoxesMachine* self);
	gboolean (*get_can_restart) (BoxesMachine* self);
	gboolean (*get_can_clone) (BoxesMachine* self);
	gboolean (*get_should_autosave) (BoxesMachine* self);
	gboolean (*get_is_local) (BoxesMachine* self);
};

struct _Block74Data {
	int _ref_count_;
	BoxesSelectionbar* self;
	BoxesMachine* machine;
};

struct _BoxesApp {
	GtkApplication parent_instance;
	BoxesAppPrivate * priv;
	BoxesCollection* collection;
	BoxesAsyncLauncher* async_launcher;
};

struct _BoxesAppClass {
	GtkApplicationClass parent_class;
};

typedef void (*BoxesCollectionCollectionForeachFunc) (BoxesCollectionItem* item, void* user_data);

static gpointer boxes_selectionbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_app_window_get_type (void) G_GNUC_CONST;
#define BOXES_SELECTIONBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarPrivate))
void boxes_selectionbar_setup_ui (BoxesSelectionbar* self, BoxesAppWindow* window);
static Block73Data* block73_data_ref (Block73Data* _data73_);
static void block73_data_unref (void * _userdata_);
static void __lambda216_ (Block73Data* _data73_);
gboolean boxes_app_window_get_selection_mode (BoxesAppWindow* self);
static void ___lambda216__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_selectionbar_on_favorite_btn_clicked (BoxesSelectionbar* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GList* boxes_app_get_selected_items (BoxesApp* self);
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
GType boxes_property_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_connect_flags_get_type (void) G_GNUC_CONST;
static void _g_object_unref0_ (gpointer var);
static inline void _g_list_free__g_object_unref0_ (GList* self);
void boxes_app_window_set_selection_mode (BoxesAppWindow* self, gboolean value);
static void _boxes_selectionbar_on_favorite_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_selectionbar_on_pause_btn_clicked (BoxesSelectionbar* self);
static Block74Data* block74_data_ref (Block74Data* _data74_);
static void block74_data_unref (void * _userdata_);
void boxes_machine_save (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_machine_save_finish (BoxesMachine* self, GAsyncResult* _res_, GError** error);
static void ____lambda217_ (Block74Data* _data74_, GObject* obj, GAsyncResult* _result_);
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
BoxesNotificationbar* boxes_app_window_get_notificationbar (BoxesAppWindow* self);
GType boxes_notification_get_type (void) G_GNUC_CONST;
BoxesNotification* boxes_notificationbar_display_error (BoxesNotificationbar* self, const gchar* message, gint timeout);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
#define BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT 6
static void _____lambda217__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static void _boxes_selectionbar_on_pause_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_selectionbar_on_open_btn_clicked (BoxesSelectionbar* self);
void boxes_app_open_selected_items_in_new_window (BoxesApp* self);
static void _boxes_selectionbar_on_open_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_selectionbar_on_remove_btn_clicked (BoxesSelectionbar* self);
void boxes_app_remove_selected_items (BoxesApp* self);
static void _boxes_selectionbar_on_remove_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self);
static void boxes_selectionbar_update_favorite_btn (BoxesSelectionbar* self);
static gboolean _vala_string_array_contains (gchar* * stack, int stack_length, gchar* needle);
static void boxes_selectionbar_update_pause_btn (BoxesSelectionbar* self);
gboolean boxes_machine_get_can_save (BoxesMachine* self);
static void boxes_selectionbar_update_delete_btn (BoxesSelectionbar* self);
GType boxes_collection_get_type (void) G_GNUC_CONST;
void boxes_collection_foreach_item (BoxesCollection* self, BoxesCollectionCollectionForeachFunc foreach_func, void* foreach_func_target);
static void __lambda218_ (BoxesSelectionbar* self, BoxesCollectionItem* item);
static void ___lambda218__boxes_collection_collection_foreach_func (BoxesCollectionItem* item, gpointer self);
static void ____lambda219_ (BoxesSelectionbar* self);
static void _____lambda219__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
gboolean boxes_machine_get_can_delete (BoxesMachine* self);
static void boxes_selectionbar_update_open_btn (BoxesSelectionbar* self);
static void __lambda220_ (BoxesSelectionbar* self, BoxesCollectionItem* item);
static void ___lambda220__boxes_collection_collection_foreach_func (BoxesCollectionItem* item, gpointer self);
static void ____lambda221_ (BoxesSelectionbar* self);
static void _____lambda221__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
gboolean boxes_libvirt_machine_get_importing (BoxesLibvirtMachine* self);
BoxesSelectionbar* boxes_selectionbar_new (void);
BoxesSelectionbar* boxes_selectionbar_construct (GType object_type);
static GObject * boxes_selectionbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _boxes_selectionbar___lambda222_ (BoxesSelectionbar* self);
static void __boxes_selectionbar___lambda222__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_selectionbar_finalize (GObject * obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static gpointer _g_object_ref0 (gpointer self) {
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	return self ? g_object_ref (self) : NULL;
#line 353 "selectionbar.c"
}


static Block73Data* block73_data_ref (Block73Data* _data73_) {
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_atomic_int_inc (&_data73_->_ref_count_);
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	return _data73_;
#line 362 "selectionbar.c"
}


static void block73_data_unref (void * _userdata_) {
	Block73Data* _data73_;
	_data73_ = (Block73Data*) _userdata_;
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	if (g_atomic_int_dec_and_test (&_data73_->_ref_count_)) {
#line 371 "selectionbar.c"
		BoxesSelectionbar* self;
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		self = _data73_->self;
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (_data73_->window);
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (self);
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		g_slice_free (Block73Data, _data73_);
#line 381 "selectionbar.c"
	}
}


static void __lambda216_ (Block73Data* _data73_) {
	BoxesSelectionbar* self;
	BoxesAppWindow* _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
#line 29 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	self = _data73_->self;
#line 30 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = _data73_->window;
#line 30 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_window_get_selection_mode (_tmp0_);
#line 30 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 30 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_revealer_set_reveal_child ((GtkRevealer*) self, _tmp2_);
#line 401 "selectionbar.c"
}


static void ___lambda216__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 29 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	__lambda216_ (self);
#line 408 "selectionbar.c"
}


void boxes_selectionbar_setup_ui (BoxesSelectionbar* self, BoxesAppWindow* window) {
	Block73Data* _data73_;
	BoxesAppWindow* _tmp0_;
	BoxesAppWindow* _tmp1_;
	BoxesAppWindow* _tmp2_;
	BoxesAppWindow* _tmp3_;
	BoxesAppWindow* _tmp4_;
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (window != NULL);
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_data73_ = g_slice_new0 (Block73Data);
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_data73_->_ref_count_ = 1;
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_data73_->self = g_object_ref (self);
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = window;
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (_data73_->window);
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_data73_->window = _tmp1_;
#line 27 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _data73_->window;
#line 27 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 27 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->window);
#line 27 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	self->priv->window = _tmp3_;
#line 29 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = _data73_->window;
#line 29 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_data ((GObject*) _tmp4_, "notify::selection-mode", (GCallback) ___lambda216__g_object_notify, block73_data_ref (_data73_), (GClosureNotify) block73_data_unref, 0);
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	block73_data_unref (_data73_);
#line 26 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_data73_ = NULL;
#line 453 "selectionbar.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 40 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 460 "selectionbar.c"
}


static inline void _g_list_free__g_object_unref0_ (GList* self) {
#line 40 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_list_free_full (self, (GDestroyNotify) _g_object_unref0_);
#line 467 "selectionbar.c"
}


static void boxes_selectionbar_on_favorite_btn_clicked (BoxesSelectionbar* self) {
	gboolean _tmp0_;
	BoxesApp* _tmp1_;
	GList* _tmp2_;
	GList* _tmp3_;
	BoxesAppWindow* _tmp13_;
#line 36 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 37 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = self->priv->ignore_favorite_btn_clicks;
#line 37 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	if (_tmp0_) {
#line 38 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		return;
#line 485 "selectionbar.c"
	}
#line 40 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_app;
#line 40 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = boxes_app_get_selected_items (_tmp1_);
#line 40 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _tmp2_;
#line 493 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp3_;
#line 40 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 501 "selectionbar.c"
			BoxesCollectionItem* _tmp4_;
			BoxesCollectionItem* item = NULL;
#line 40 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			_tmp4_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 40 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			item = _tmp4_;
#line 508 "selectionbar.c"
			{
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp5_;
				BoxesMachine* _tmp6_;
				BoxesMachine* _tmp7_;
				BoxesMachine* _tmp8_;
				BoxesBoxConfig* _tmp9_;
				GtkToggleButton* _tmp10_;
				gboolean _tmp11_;
				gboolean _tmp12_;
#line 41 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = item;
#line 41 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp5_) : NULL);
#line 41 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				machine = _tmp6_;
#line 42 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = machine;
#line 42 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				if (_tmp7_ == NULL) {
#line 43 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (machine);
#line 43 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 43 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					continue;
#line 535 "selectionbar.c"
				}
#line 44 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp8_ = machine;
#line 44 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp9_ = _tmp8_->config;
#line 44 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp10_ = self->priv->favorite_btn;
#line 44 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp11_ = gtk_toggle_button_get_active (_tmp10_);
#line 44 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp12_ = _tmp11_;
#line 44 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				boxes_box_config_set_category (_tmp9_, "favorite", _tmp12_);
#line 40 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (machine);
#line 40 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 553 "selectionbar.c"
			}
		}
#line 40 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 558 "selectionbar.c"
	}
#line 47 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp13_ = self->priv->window;
#line 47 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_app_window_set_selection_mode (_tmp13_, FALSE);
#line 564 "selectionbar.c"
}


static void _boxes_selectionbar_on_favorite_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_on_favorite_btn_clicked ((BoxesSelectionbar*) self);
#line 571 "selectionbar.c"
}


static Block74Data* block74_data_ref (Block74Data* _data74_) {
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_atomic_int_inc (&_data74_->_ref_count_);
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	return _data74_;
#line 580 "selectionbar.c"
}


static void block74_data_unref (void * _userdata_) {
	Block74Data* _data74_;
	_data74_ = (Block74Data*) _userdata_;
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	if (g_atomic_int_dec_and_test (&_data74_->_ref_count_)) {
#line 589 "selectionbar.c"
		BoxesSelectionbar* self;
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		self = _data74_->self;
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (_data74_->machine);
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (self);
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		g_slice_free (Block74Data, _data74_);
#line 599 "selectionbar.c"
	}
}


static void ____lambda217_ (Block74Data* _data74_, GObject* obj, GAsyncResult* _result_) {
	BoxesSelectionbar* self;
	GError * _inner_error_ = NULL;
#line 56 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	self = _data74_->self;
#line 56 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (_result_ != NULL);
#line 611 "selectionbar.c"
	{
		BoxesMachine* _tmp0_;
		GAsyncResult* _tmp1_;
#line 58 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp0_ = _data74_->machine;
#line 58 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp1_ = _result_;
#line 58 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		boxes_machine_save_finish (_tmp0_, _tmp1_, &_inner_error_);
#line 58 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 623 "selectionbar.c"
			goto __catch76_g_error;
		}
	}
	goto __finally76;
	__catch76_g_error:
	{
		GError* e = NULL;
		BoxesAppWindow* _tmp2_;
		BoxesNotificationbar* _tmp3_;
		BoxesNotificationbar* _tmp4_;
		BoxesMachine* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_;
		gchar* _tmp8_;
		gchar* _tmp9_;
		BoxesNotification* _tmp10_;
		BoxesNotification* _tmp11_;
#line 57 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		e = _inner_error_;
#line 57 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_inner_error_ = NULL;
#line 60 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp2_ = self->priv->window;
#line 60 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp3_ = boxes_app_window_get_notificationbar (_tmp2_);
#line 60 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp4_ = _tmp3_;
#line 60 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp5_ = _data74_->machine;
#line 60 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp6_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _tmp5_);
#line 60 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp7_ = _tmp6_;
#line 60 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp8_ = g_strdup_printf (_ ("Pausing “%s” failed"), _tmp7_);
#line 60 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp9_ = _tmp8_;
#line 60 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp10_ = boxes_notificationbar_display_error (_tmp4_, _tmp9_, BOXES_NOTIFICATIONBAR_DEFAULT_TIMEOUT);
#line 60 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp11_ = _tmp10_;
#line 60 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_g_object_unref0 (_tmp11_);
#line 60 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_g_free0 (_tmp9_);
#line 57 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_g_error_free0 (e);
#line 671 "selectionbar.c"
	}
	__finally76:
#line 57 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 57 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 57 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		g_clear_error (&_inner_error_);
#line 57 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		return;
#line 682 "selectionbar.c"
	}
}


static void _____lambda217__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 56 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	____lambda217_ (self, source_object, res);
#line 56 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	block74_data_unref (self);
#line 692 "selectionbar.c"
}


static void boxes_selectionbar_on_pause_btn_clicked (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_;
	GList* _tmp1_;
	GList* _tmp2_;
	GtkButton* _tmp8_;
	BoxesAppWindow* _tmp9_;
#line 51 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 710 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp2_;
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 718 "selectionbar.c"
			BoxesCollectionItem* _tmp3_;
			BoxesCollectionItem* item = NULL;
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			_tmp3_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			item = _tmp3_;
#line 725 "selectionbar.c"
			{
				Block74Data* _data74_;
				BoxesCollectionItem* _tmp4_;
				BoxesMachine* _tmp5_;
				BoxesMachine* _tmp6_;
				BoxesMachine* _tmp7_;
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_data74_ = g_slice_new0 (Block74Data);
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_data74_->_ref_count_ = 1;
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_data74_->self = g_object_ref (self);
#line 53 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp4_ = item;
#line 53 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp4_) : NULL);
#line 53 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_data74_->machine = _tmp5_;
#line 54 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = _data74_->machine;
#line 54 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				if (_tmp6_ == NULL) {
#line 55 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 55 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					block74_data_unref (_data74_);
#line 55 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_data74_ = NULL;
#line 55 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					continue;
#line 756 "selectionbar.c"
				}
#line 56 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = _data74_->machine;
#line 56 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				boxes_machine_save (_tmp7_, _____lambda217__gasync_ready_callback, block74_data_ref (_data74_));
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				block74_data_unref (_data74_);
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_data74_ = NULL;
#line 768 "selectionbar.c"
			}
		}
#line 52 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 773 "selectionbar.c"
	}
#line 65 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp8_ = self->priv->pause_btn;
#line 65 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp8_, FALSE);
#line 66 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp9_ = self->priv->window;
#line 66 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_app_window_set_selection_mode (_tmp9_, FALSE);
#line 783 "selectionbar.c"
}


static void _boxes_selectionbar_on_pause_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_on_pause_btn_clicked ((BoxesSelectionbar*) self);
#line 790 "selectionbar.c"
}


static void boxes_selectionbar_on_open_btn_clicked (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_;
#line 70 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 71 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 71 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_app_open_selected_items_in_new_window (_tmp0_);
#line 802 "selectionbar.c"
}


static void _boxes_selectionbar_on_open_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_on_open_btn_clicked ((BoxesSelectionbar*) self);
#line 809 "selectionbar.c"
}


static void boxes_selectionbar_on_remove_btn_clicked (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_;
#line 75 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 76 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 76 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_app_remove_selected_items (_tmp0_);
#line 821 "selectionbar.c"
}


static void _boxes_selectionbar_on_remove_btn_clicked_gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_on_remove_btn_clicked ((BoxesSelectionbar*) self);
#line 828 "selectionbar.c"
}


static gboolean _vala_string_array_contains (gchar* * stack, int stack_length, gchar* needle) {
	int i;
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	for (i = 0; i < stack_length; i++) {
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			return TRUE;
#line 840 "selectionbar.c"
		}
	}
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	return FALSE;
#line 845 "selectionbar.c"
}


static void boxes_selectionbar_update_favorite_btn (BoxesSelectionbar* self) {
	gboolean active = FALSE;
	gboolean sensitive = FALSE;
	BoxesApp* _tmp0_;
	GList* _tmp1_;
	GList* _tmp2_;
	GList* _tmp3_;
	guint _tmp4_;
	gboolean _tmp5_;
	BoxesApp* _tmp6_;
	GList* _tmp7_;
	GList* _tmp8_;
	GtkToggleButton* _tmp22_;
	gboolean _tmp23_;
	GtkToggleButton* _tmp24_;
	gboolean _tmp25_;
#line 79 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 80 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	active = FALSE;
#line 81 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 81 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 81 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 81 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = _tmp2_;
#line 81 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = g_list_length (_tmp3_);
#line 81 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp5_ = _tmp4_ > ((guint) 0);
#line 81 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp3_);
#line 81 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	sensitive = _tmp5_;
#line 83 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp6_ = boxes_app_app;
#line 83 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp7_ = boxes_app_get_selected_items (_tmp6_);
#line 83 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp8_ = _tmp7_;
#line 891 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 83 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp8_;
#line 83 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 899 "selectionbar.c"
			BoxesCollectionItem* _tmp9_;
			BoxesCollectionItem* item = NULL;
#line 83 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			_tmp9_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 83 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			item = _tmp9_;
#line 906 "selectionbar.c"
			{
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp10_;
				BoxesMachine* _tmp11_;
				BoxesMachine* _tmp12_;
				gboolean is_favorite = FALSE;
				BoxesMachine* _tmp13_;
				BoxesBoxConfig* _tmp14_;
				gchar** _tmp15_;
				gint _tmp15__length1;
				gchar** _tmp16_;
				gint _tmp16__length1;
				gchar** _tmp17_;
				gint _tmp17__length1;
				gboolean _tmp18_;
				gboolean _tmp19_;
#line 84 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp10_ = item;
#line 84 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp11_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp10_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp10_) : NULL);
#line 84 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				machine = _tmp11_;
#line 85 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp12_ = machine;
#line 85 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				if (_tmp12_ == NULL) {
#line 86 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (machine);
#line 86 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 86 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					continue;
#line 939 "selectionbar.c"
				}
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp13_ = machine;
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp14_ = _tmp13_->config;
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp15_ = boxes_box_config_get_categories (_tmp14_, &_tmp15__length1);
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp16_ = _tmp15_;
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp16__length1 = _tmp15__length1;
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp17_ = _tmp16_;
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp17__length1 = _tmp16__length1;
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp18_ = _vala_string_array_contains (_tmp17_, _tmp16__length1, "favorite");
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp17_ = (_vala_array_free (_tmp17_, _tmp17__length1, (GDestroyNotify) g_free), NULL);
#line 88 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				is_favorite = _tmp18_;
#line 89 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp19_ = active;
#line 89 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				if (!_tmp19_) {
#line 965 "selectionbar.c"
					gboolean _tmp20_;
#line 90 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_tmp20_ = is_favorite;
#line 90 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					active = _tmp20_;
#line 971 "selectionbar.c"
				} else {
					gboolean _tmp21_;
#line 91 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_tmp21_ = is_favorite;
#line 91 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					if (!_tmp21_) {
#line 92 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
						sensitive = FALSE;
#line 93 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
						_g_object_unref0 (machine);
#line 93 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
						_g_object_unref0 (item);
#line 93 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
						break;
#line 986 "selectionbar.c"
					}
				}
#line 83 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (machine);
#line 83 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 993 "selectionbar.c"
			}
		}
#line 83 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 998 "selectionbar.c"
	}
#line 97 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	self->priv->ignore_favorite_btn_clicks = TRUE;
#line 98 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp22_ = self->priv->favorite_btn;
#line 98 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp23_ = active;
#line 98 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_toggle_button_set_active (_tmp22_, _tmp23_);
#line 99 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp24_ = self->priv->favorite_btn;
#line 99 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp25_ = sensitive;
#line 99 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp24_, _tmp25_);
#line 100 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	self->priv->ignore_favorite_btn_clicks = FALSE;
#line 1016 "selectionbar.c"
}


static void boxes_selectionbar_update_pause_btn (BoxesSelectionbar* self) {
	gboolean sensitive = FALSE;
	BoxesApp* _tmp0_;
	GList* _tmp1_;
	GList* _tmp2_;
	GtkButton* _tmp10_;
	gboolean _tmp11_;
#line 103 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 104 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	sensitive = FALSE;
#line 105 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 105 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 105 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = _tmp1_;
#line 1037 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 105 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp2_;
#line 105 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1045 "selectionbar.c"
			BoxesCollectionItem* _tmp3_;
			BoxesCollectionItem* item = NULL;
#line 105 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			_tmp3_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 105 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			item = _tmp3_;
#line 1052 "selectionbar.c"
			{
				BoxesCollectionItem* _tmp4_;
				BoxesMachine* machine = NULL;
				BoxesCollectionItem* _tmp5_;
				BoxesMachine* _tmp6_;
				BoxesMachine* _tmp7_;
				gboolean _tmp8_;
				gboolean _tmp9_;
#line 106 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp4_ = item;
#line 106 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, BOXES_TYPE_MACHINE)) {
#line 107 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 107 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					continue;
#line 1069 "selectionbar.c"
				}
#line 109 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp5_ = item;
#line 109 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp5_) : NULL);
#line 109 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				machine = _tmp6_;
#line 110 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp7_ = machine;
#line 110 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp8_ = boxes_machine_get_can_save (_tmp7_);
#line 110 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp9_ = _tmp8_;
#line 110 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				if (_tmp9_) {
#line 111 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					sensitive = TRUE;
#line 113 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (machine);
#line 113 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 113 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					break;
#line 1093 "selectionbar.c"
				}
#line 105 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (machine);
#line 105 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1099 "selectionbar.c"
			}
		}
#line 105 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 1104 "selectionbar.c"
	}
#line 117 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp10_ = self->priv->pause_btn;
#line 117 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp11_ = sensitive;
#line 117 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp10_, _tmp11_);
#line 1112 "selectionbar.c"
}


static void __lambda218_ (BoxesSelectionbar* self, BoxesCollectionItem* item) {
	gulong can_delete_id = 0UL;
	BoxesCollectionItem* _tmp0_;
	gconstpointer _tmp1_;
	gulong _tmp2_;
#line 121 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (item != NULL);
#line 122 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = item;
#line 122 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "can_delete_id");
#line 122 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	can_delete_id = (gulong) ((guintptr) _tmp1_);
#line 123 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = can_delete_id;
#line 123 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	if (_tmp2_ > ((gulong) 0)) {
#line 1133 "selectionbar.c"
		BoxesCollectionItem* _tmp3_;
		gulong _tmp4_;
		BoxesCollectionItem* _tmp5_;
#line 124 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp3_ = item;
#line 124 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp4_ = can_delete_id;
#line 124 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		g_signal_handler_disconnect ((GObject*) _tmp3_, _tmp4_);
#line 125 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp5_ = item;
#line 125 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		g_object_set_data_full ((GObject*) _tmp5_, "can_delete_id", (gpointer) ((guintptr) ((gulong) 0)), NULL);
#line 1147 "selectionbar.c"
	}
}


static void ___lambda218__boxes_collection_collection_foreach_func (BoxesCollectionItem* item, gpointer self) {
#line 121 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	__lambda218_ ((BoxesSelectionbar*) self, item);
#line 1155 "selectionbar.c"
}


static void ____lambda219_ (BoxesSelectionbar* self) {
#line 133 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_delete_btn (self);
#line 1162 "selectionbar.c"
}


static void _____lambda219__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 132 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	____lambda219_ ((BoxesSelectionbar*) self);
#line 1169 "selectionbar.c"
}


static void boxes_selectionbar_update_delete_btn (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_;
	BoxesCollection* _tmp1_;
	gboolean sensitive = FALSE;
	BoxesApp* _tmp2_;
	GList* _tmp3_;
	GList* _tmp4_;
	GList* _tmp5_;
	guint _tmp6_;
	gboolean _tmp7_;
	BoxesApp* _tmp8_;
	GList* _tmp9_;
	GList* _tmp10_;
	GtkButton* _tmp21_;
	gboolean _tmp22_;
#line 120 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 121 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 121 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = _tmp0_->collection;
#line 121 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_collection_foreach_item (_tmp1_, ___lambda218__boxes_collection_collection_foreach_func, self);
#line 129 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = boxes_app_app;
#line 129 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = boxes_app_get_selected_items (_tmp2_);
#line 129 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = _tmp3_;
#line 129 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp5_ = _tmp4_;
#line 129 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp6_ = g_list_length (_tmp5_);
#line 129 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp7_ = _tmp6_ > ((guint) 0);
#line 129 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp5_);
#line 129 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	sensitive = _tmp7_;
#line 130 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp8_ = boxes_app_app;
#line 130 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp9_ = boxes_app_get_selected_items (_tmp8_);
#line 130 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp10_ = _tmp9_;
#line 1218 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 130 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp10_;
#line 130 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1226 "selectionbar.c"
			BoxesCollectionItem* _tmp11_;
			BoxesCollectionItem* item = NULL;
#line 130 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			_tmp11_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 130 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			item = _tmp11_;
#line 1233 "selectionbar.c"
			{
				gulong can_delete_id = 0UL;
				BoxesCollectionItem* _tmp12_;
				gulong _tmp13_;
				BoxesCollectionItem* _tmp14_;
				gulong _tmp15_;
				gboolean _tmp16_ = FALSE;
				BoxesCollectionItem* _tmp17_;
#line 131 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				can_delete_id = (gulong) 0;
#line 132 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp12_ = item;
#line 132 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp13_ = g_signal_connect_object ((GObject*) _tmp12_, "notify::can-delete", (GCallback) _____lambda219__g_object_notify, self, 0);
#line 132 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				can_delete_id = _tmp13_;
#line 135 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp14_ = item;
#line 135 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp15_ = can_delete_id;
#line 135 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				g_object_set_data_full ((GObject*) _tmp14_, "can_delete_id", (gpointer) ((guintptr) _tmp15_), NULL);
#line 137 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp17_ = item;
#line 137 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp17_, BOXES_TYPE_MACHINE)) {
#line 1260 "selectionbar.c"
					BoxesCollectionItem* _tmp18_;
					gboolean _tmp19_;
					gboolean _tmp20_;
#line 137 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_tmp18_ = item;
#line 137 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_tmp19_ = boxes_machine_get_can_delete (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, BOXES_TYPE_MACHINE) ? ((BoxesMachine*) _tmp18_) : NULL);
#line 137 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_tmp20_ = _tmp19_;
#line 137 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_tmp16_ = !_tmp20_;
#line 1272 "selectionbar.c"
				} else {
#line 137 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_tmp16_ = FALSE;
#line 1276 "selectionbar.c"
				}
#line 137 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				if (_tmp16_) {
#line 138 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					sensitive = FALSE;
#line 139 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 139 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					break;
#line 1286 "selectionbar.c"
				}
#line 130 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1290 "selectionbar.c"
			}
		}
#line 130 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 1295 "selectionbar.c"
	}
#line 143 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp21_ = self->priv->remove_btn;
#line 143 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp22_ = sensitive;
#line 143 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp21_, _tmp22_);
#line 1303 "selectionbar.c"
}


static void __lambda220_ (BoxesSelectionbar* self, BoxesCollectionItem* item) {
	gulong importing_id = 0UL;
	BoxesCollectionItem* _tmp0_;
	gconstpointer _tmp1_;
	gulong _tmp2_;
#line 147 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (item != NULL);
#line 148 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = item;
#line 148 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = g_object_get_data ((GObject*) _tmp0_, "importing_id");
#line 148 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	importing_id = (gulong) ((guintptr) _tmp1_);
#line 149 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = importing_id;
#line 149 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	if (_tmp2_ > ((gulong) 0)) {
#line 1324 "selectionbar.c"
		BoxesCollectionItem* _tmp3_;
		gulong _tmp4_;
		BoxesCollectionItem* _tmp5_;
#line 150 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp3_ = item;
#line 150 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp4_ = importing_id;
#line 150 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		g_signal_handler_disconnect ((GObject*) _tmp3_, _tmp4_);
#line 151 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp5_ = item;
#line 151 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		g_object_set_data_full ((GObject*) _tmp5_, "importing_id", (gpointer) ((guintptr) ((gulong) 0)), NULL);
#line 1338 "selectionbar.c"
	}
}


static void ___lambda220__boxes_collection_collection_foreach_func (BoxesCollectionItem* item, gpointer self) {
#line 147 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	__lambda220_ ((BoxesSelectionbar*) self, item);
#line 1346 "selectionbar.c"
}


static void ____lambda221_ (BoxesSelectionbar* self) {
#line 160 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_open_btn (self);
#line 1353 "selectionbar.c"
}


static void _____lambda221__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 159 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	____lambda221_ ((BoxesSelectionbar*) self);
#line 1360 "selectionbar.c"
}


static void boxes_selectionbar_update_open_btn (BoxesSelectionbar* self) {
	BoxesApp* _tmp0_;
	BoxesCollection* _tmp1_;
	guint items = 0U;
	BoxesApp* _tmp2_;
	GList* _tmp3_;
	GList* _tmp4_;
	GList* _tmp5_;
	guint _tmp6_;
	guint _tmp7_;
	gboolean sensitive = FALSE;
	guint _tmp8_;
	BoxesApp* _tmp9_;
	GList* _tmp10_;
	GList* _tmp11_;
	GtkButton* _tmp22_;
	gboolean _tmp23_;
	guint _tmp24_;
#line 146 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_return_if_fail (self != NULL);
#line 147 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 147 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp1_ = _tmp0_->collection;
#line 147 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_collection_foreach_item (_tmp1_, ___lambda220__boxes_collection_collection_foreach_func, self);
#line 155 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp2_ = boxes_app_app;
#line 155 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp3_ = boxes_app_get_selected_items (_tmp2_);
#line 155 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp4_ = _tmp3_;
#line 155 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp5_ = _tmp4_;
#line 155 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp6_ = g_list_length (_tmp5_);
#line 155 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp7_ = _tmp6_;
#line 155 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp5_);
#line 155 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	items = _tmp7_;
#line 156 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp8_ = items;
#line 156 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	sensitive = _tmp8_ > ((guint) 0);
#line 157 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp9_ = boxes_app_app;
#line 157 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp10_ = boxes_app_get_selected_items (_tmp9_);
#line 157 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp11_ = _tmp10_;
#line 1416 "selectionbar.c"
	{
		GList* item_collection = NULL;
		GList* item_it = NULL;
#line 157 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		item_collection = _tmp11_;
#line 157 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		for (item_it = item_collection; item_it != NULL; item_it = item_it->next) {
#line 1424 "selectionbar.c"
			BoxesCollectionItem* _tmp12_;
			BoxesCollectionItem* item = NULL;
#line 157 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			_tmp12_ = _g_object_ref0 ((BoxesCollectionItem*) item_it->data);
#line 157 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
			item = _tmp12_;
#line 1431 "selectionbar.c"
			{
				gulong importing_id = 0UL;
				BoxesCollectionItem* _tmp13_;
				gulong _tmp14_;
				BoxesCollectionItem* _tmp15_;
				gulong _tmp16_;
				gboolean _tmp17_ = FALSE;
				BoxesCollectionItem* _tmp18_;
#line 158 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				importing_id = (gulong) 0;
#line 159 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp13_ = item;
#line 159 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp14_ = g_signal_connect_object ((GObject*) _tmp13_, "notify::importing", (GCallback) _____lambda221__g_object_notify, self, 0);
#line 159 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				importing_id = _tmp14_;
#line 162 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp15_ = item;
#line 162 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp16_ = importing_id;
#line 162 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				g_object_set_data_full ((GObject*) _tmp15_, "importing_id", (gpointer) ((guintptr) _tmp16_), NULL);
#line 164 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_tmp18_ = item;
#line 164 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, BOXES_TYPE_LIBVIRT_MACHINE)) {
#line 1458 "selectionbar.c"
					BoxesCollectionItem* _tmp19_;
					gboolean _tmp20_;
					gboolean _tmp21_;
#line 164 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_tmp19_ = item;
#line 164 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_tmp20_ = boxes_libvirt_machine_get_importing (G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, BOXES_TYPE_LIBVIRT_MACHINE) ? ((BoxesLibvirtMachine*) _tmp19_) : NULL);
#line 164 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_tmp21_ = _tmp20_;
#line 164 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_tmp17_ = _tmp21_;
#line 1470 "selectionbar.c"
				} else {
#line 164 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_tmp17_ = FALSE;
#line 1474 "selectionbar.c"
				}
#line 164 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				if (_tmp17_) {
#line 165 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					sensitive = FALSE;
#line 166 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					_g_object_unref0 (item);
#line 166 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
					break;
#line 1484 "selectionbar.c"
				}
#line 157 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
				_g_object_unref0 (item);
#line 1488 "selectionbar.c"
			}
		}
#line 157 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		__g_list_free__g_object_unref0_0 (item_collection);
#line 1493 "selectionbar.c"
	}
#line 169 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp22_ = self->priv->open_btn;
#line 169 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp23_ = sensitive;
#line 169 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp22_, _tmp23_);
#line 171 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp24_ = items;
#line 171 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	if (_tmp24_ == ((guint) 0)) {
#line 1505 "selectionbar.c"
		GtkButton* _tmp25_;
#line 173 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp25_ = self->priv->open_btn;
#line 173 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		gtk_button_set_label (_tmp25_, C_ ("0 items selected", "_Open in new window"));
#line 1511 "selectionbar.c"
	} else {
		GtkButton* _tmp26_;
		guint _tmp27_;
		guint _tmp28_;
		gchar* _tmp29_;
		gchar* _tmp30_;
#line 175 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp26_ = self->priv->open_btn;
#line 175 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp27_ = items;
#line 175 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp28_ = items;
#line 175 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp29_ = g_strdup_printf (ngettext ("_Open in new window", "_Open in %u new windows", (gulong) _tmp27_), _tmp28_);
#line 175 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_tmp30_ = _tmp29_;
#line 175 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		gtk_button_set_label (_tmp26_, _tmp30_);
#line 175 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
		_g_free0 (_tmp30_);
#line 1532 "selectionbar.c"
	}
}


BoxesSelectionbar* boxes_selectionbar_construct (GType object_type) {
	BoxesSelectionbar * self = NULL;
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	self = (BoxesSelectionbar*) g_object_new (object_type, NULL);
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	return self;
#line 1543 "selectionbar.c"
}


BoxesSelectionbar* boxes_selectionbar_new (void) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	return boxes_selectionbar_construct (BOXES_TYPE_SELECTIONBAR);
#line 1550 "selectionbar.c"
}


static void _boxes_selectionbar___lambda222_ (BoxesSelectionbar* self) {
#line 19 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_favorite_btn (self);
#line 20 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_pause_btn (self);
#line 21 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_delete_btn (self);
#line 22 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_update_open_btn (self);
#line 1563 "selectionbar.c"
}


static void __boxes_selectionbar___lambda222__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 18 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_boxes_selectionbar___lambda222_ ((BoxesSelectionbar*) self);
#line 1570 "selectionbar.c"
}


static GObject * boxes_selectionbar_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesSelectionbar * self;
	BoxesApp* _tmp0_;
#line 17 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	parent_class = G_OBJECT_CLASS (boxes_selectionbar_parent_class);
#line 17 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 17 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar);
#line 18 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_tmp0_ = boxes_app_app;
#line 18 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_signal_connect_object ((GObject*) _tmp0_, "notify::selected-items", (GCallback) __boxes_selectionbar___lambda222__g_object_notify, self, 0);
#line 17 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	return obj;
#line 1591 "selectionbar.c"
}


static void boxes_selectionbar_class_init (BoxesSelectionbarClass * klass) {
	gint BoxesSelectionbar_private_offset;
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	boxes_selectionbar_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesSelectionbarPrivate));
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_selectionbar_constructor;
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_selectionbar_finalize;
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	BoxesSelectionbar_private_offset = g_type_class_get_instance_private_offset (klass);
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_set_template_from_resource (GTK_WIDGET_CLASS (klass), "/org/gnome/Boxes/ui/selectionbar.ui");
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "favorite_btn", FALSE, BoxesSelectionbar_private_offset + G_STRUCT_OFFSET (BoxesSelectionbarPrivate, favorite_btn));
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "pause_btn", FALSE, BoxesSelectionbar_private_offset + G_STRUCT_OFFSET (BoxesSelectionbarPrivate, pause_btn));
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "remove_btn", FALSE, BoxesSelectionbar_private_offset + G_STRUCT_OFFSET (BoxesSelectionbarPrivate, remove_btn));
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_child_full (GTK_WIDGET_CLASS (klass), "open_btn", FALSE, BoxesSelectionbar_private_offset + G_STRUCT_OFFSET (BoxesSelectionbarPrivate, open_btn));
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_favorite_btn_clicked", G_CALLBACK(_boxes_selectionbar_on_favorite_btn_clicked_gtk_button_clicked));
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_pause_btn_clicked", G_CALLBACK(_boxes_selectionbar_on_pause_btn_clicked_gtk_button_clicked));
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_open_btn_clicked", G_CALLBACK(_boxes_selectionbar_on_open_btn_clicked_gtk_button_clicked));
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_class_bind_template_callback_full (GTK_WIDGET_CLASS (klass), "on_remove_btn_clicked", G_CALLBACK(_boxes_selectionbar_on_remove_btn_clicked_gtk_button_clicked));
#line 1625 "selectionbar.c"
}


static void boxes_selectionbar_instance_init (BoxesSelectionbar * self) {
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	self->priv = BOXES_SELECTIONBAR_GET_PRIVATE (self);
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	gtk_widget_init_template (GTK_WIDGET (self));
#line 1634 "selectionbar.c"
}


static void boxes_selectionbar_finalize (GObject * obj) {
	BoxesSelectionbar * self;
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar);
#line 7 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->favorite_btn);
#line 9 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->pause_btn);
#line 11 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->remove_btn);
#line 13 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->open_btn);
#line 15 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	_g_object_unref0 (self->priv->window);
#line 5 "/home/fborges/checkout/gnome-boxes/src/selectionbar.vala"
	G_OBJECT_CLASS (boxes_selectionbar_parent_class)->finalize (obj);
#line 1654 "selectionbar.c"
}


GType boxes_selectionbar_get_type (void) {
	static volatile gsize boxes_selectionbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_selectionbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesSelectionbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_selectionbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesSelectionbar), 0, (GInstanceInitFunc) boxes_selectionbar_instance_init, NULL };
		GType boxes_selectionbar_type_id;
		boxes_selectionbar_type_id = g_type_register_static (gtk_revealer_get_type (), "BoxesSelectionbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_selectionbar_type_id__volatile, boxes_selectionbar_type_id);
	}
	return boxes_selectionbar_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 1673 "selectionbar.c"
		int i;
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 1681 "selectionbar.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 535 "/home/fborges/checkout/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 1693 "selectionbar.c"
}



